Site Vistor Goals
=================

Participate in the community or operations of the site
------------------------------------------------------

- :doc:`BecomeAMember`

- "Log into the site":LoginAsMember

- "Browse community news":BrowseNewsItems

- **XXX** "Submit a news item":SubmitNewsItem

  o Not a stock use case for anonymous visitors;  see
    "Create Content":CreateNewContent and "Submit
    Content":SubmitContentForPublication for Content
    Creator's take.

  * Quickly find content that is important to him

    - "Browse the site homepage":BrowseCMFSiteHomepage

    - **XXX** "Browse a portal topic":BrowsePortalTopic

    - "Search site for information":SearchCMFSite

  * Improve relevance and usability of site information

    - "Configure personalization options":ConfigurePersonalization

    - "Provide feedback on content":ProvideFeedback
